Status

Enum Status 

#[non_exhaustive]
#[repr(u32)]
pub enum Status {
Show 13 variants Ok = 0, NotFound = 1, BadArgument = 2, SerializationFailure = 3, ParseFailure = 4, BadExpression = 5, InvalidMemoryAccess = 6, Empty = 7, CasMismatch = 8, ResultMismatch = 9, InternalFailure = 10, BrokenConnection = 11, Unimplemented = 12,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ok = 0



NotFound = 1

The result could not be found, e.g. a provided key did not appear in a table.



BadArgument = 2

An argument was bad, e.g. did not not conform to the required range.



SerializationFailure = 3

A protobuf could not be serialized.



ParseFailure = 4

A protobuf could not be parsed.



BadExpression = 5

A provided expression (e.g. “foo.bar”) was illegal or unrecognized.



InvalidMemoryAccess = 6

A provided memory range was not legal.



Empty = 7

Data was requested from an empty container.



CasMismatch = 8

The provided CAS did not match that of the stored data.



ResultMismatch = 9

Returned result was unexpected, e.g. of the incorrect size.



InternalFailure = 10

Internal failure: trying check logs of the surrounding system.



BrokenConnection = 11

The connection/stream/pipe was broken/closed unexpectedly.



Unimplemented = 12

Feature not implemented.