pub enum UserAgentVersionType {
UserAgentVersion(String),
UserAgentBuildVersion(BuildVersion),
}Variants
UserAgentVersion(String)
Free-form string that identifies the version of the entity requesting config. E.g. “1.12.2” or “abcd1234”, or “SpecialEnvoyBuild”
UserAgentBuildVersion(BuildVersion)
Structured version of the entity requesting config.
Implementations
Sourceimpl UserAgentVersionType
impl UserAgentVersionType
Sourcepub fn merge<B>(
field: &mut Option<UserAgentVersionType>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<UserAgentVersionType>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.