pub enum PortSpecifier {
PortValue(u32),
NamedPort(String),
}Variants
PortValue(u32)
NamedPort(String)
This is only valid if :ref:resolver_name <envoy_v3_api_field_config.core.v3.SocketAddress.resolver_name> is specified below and the
named resolver is capable of named port resolution.
Implementations
Sourceimpl PortSpecifier
impl PortSpecifier
Sourcepub fn merge<B>(
field: &mut Option<PortSpecifier>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<PortSpecifier>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.