pub struct MetadataAttributes(/* private fields */);Expand description
Data exchanged between filters is available as the following attributes Note that these attributes may change during the life of a request as the data can be updated by filters at any point.
Implementations