pub struct ResponseAttributes(/* private fields */);Expand description
Available in HTTP filters during a response.
Implementations
Sourceimpl ResponseAttributes
impl ResponseAttributes
Sourcepub fn code_details(&self) -> Option<String>
pub fn code_details(&self) -> Option<String>
Internal response code details (subject to change)
Sourcepub fn flags(&self) -> Option<u64>
pub fn flags(&self) -> Option<u64>
Additional details about the response beyond the standard response code encoded as a bit-vector
Sourcepub fn grpc_status(&self) -> Option<u32>
pub fn grpc_status(&self) -> Option<u32>
Response gRPC status code
Sourcepub fn headers(&self) -> Option<Vec<(String, Vec<u8>)>>
pub fn headers(&self) -> Option<Vec<(String, Vec<u8>)>>
All response headers indexed by the lower-cased header name Header values in response.headers associative array are comma-concatenated in case of multiple values.
Sourcepub fn trailers(&self) -> Option<Vec<(String, Vec<u8>)>>
pub fn trailers(&self) -> Option<Vec<(String, Vec<u8>)>>
All response trailers indexed by the lower-cased trailer name Header values in response.trailers associative array are comma-concatenated in case of multiple values.
Sourcepub fn total_size(&self) -> Option<usize>
pub fn total_size(&self) -> Option<usize>
Total size of the response including the approximate uncompressed size of the headers and the trailers