pub trait BaseContext { // Provided methods fn on_log(&mut self) { ... } fn on_done(&mut self) -> bool { ... } }
Called for access log WASM plugins. Not well supported in this crate. Unclear what context this gets called on.
Called when all processing is complete in the proxy for this context. If returns true, the context is deleted immediately (i.e. dropped). If returns false, then the drop is deferred
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".